@@ -1,12 +1,12 @@
 import uuid
 import threading
 import time
-from .config import WorkerIdentity, GrpcHost, GrpcPort
 import logging
 import grpc
-import WorkerBroker_pb2_grpc
-import WorkerBroker_pb2
-from WorkerBroker_pb2 import ReportStatusRequest, ReportProgressRequest
+
+from .WorkerBroker_pb2_grpc import WorkerBrokerStub
+from .config import WorkerIdentity, GrpcHost, GrpcPort
+from .WorkerBroker_pb2 import ReportStatusRequest, ReportProgressRequest
 
 logger = logging.getLogger(__name__)
 
@@ -31,7 +31,7 @@ class AlgorithmDaemon:
                     f" connection agent service {GrpcHost}:{GrpcPort}")
         self.__channel = grpc.insecure_channel(
             f'{GrpcHost}:{GrpcPort}')
-        self.__worker_stub = WorkerBroker_pb2_grpc.WorkerBrokerStub(
+        self.__worker_stub = WorkerBrokerStub(
             self.__channel)
         # pylint: disable=maybe-no-member
         self.__worker_stub.ReportStatus(ReportStatusRequest(
